@@ -1,26 +1,12 @@
-import json
 import operator
 from functools import reduce
-from typing import Any, Dict, Optional, Tuple
+from typing import Tuple
 
 from accession.backends import GCBackend
 from accession.file import GSFile
 from accession.task import Task
 
 
-class MetaData:
-    def __init__(self, metadata_filepath: str) -> None:
-        self._metadata_filepath = metadata_filepath
-        self._content: Optional[Dict[str, Any]] = None
-
-    @property
-    def content(self) -> Dict[str, Any]:
-        if self._content is None:
-            with open(self._metadata_filepath) as fp:
-                self._content = json.load(fp)
-        return self._content
-
-
 class Analysis:
     """
     Parses Cromwell workflow metadata into a searchable digraph
@@ -44,12 +30,16 @@ class Analysis:
         if auto_populate:
             self.tasks = self.make_tasks()
 
-    # Makes instances of Task
     def make_tasks(self):
+        """
+        Makes instances of Task. If the task did not succeed then will not add it to the
+        call graph.
+        """
         tasks = []
         for key, value in self.metadata["calls"].items():
             for task in value:
-                tasks.append(self.make_task(key, task))
+                if task["executionStatus"] == "Done":
+                    tasks.append(self.make_task(key, task))
         for task in tasks:
             task.output_files = self.get_or_make_files(task.outputs, task)
         # Making input files after making output files avoids creating
