@@ -55,6 +55,23 @@ def ok_response():
     return r
 
 
+@pytest.fixture
+def matching_md5_record():
+    record = MatchingMd5Record(
+        "gs://file/a",
+        [
+            EncodeFile(
+                {
+                    "@id": "/files/ENCFFABC123/",
+                    "status": "released",
+                    "dataset": "ENCSRCBA321",
+                }
+            )
+        ],
+    )
+    return record
+
+
 def test_accession_genome_annotation(mock_accession):
     assert super(AccessionMicroRna, mock_accession).genome_annotation is None
 
@@ -308,6 +325,22 @@ def test_get_derived_from_all(mirna_accessioner):
     assert set(accession_ids) == set(ancestor_accessions)
 
 
+@pytest.mark.parametrize(
+    "file_size_bytes,expected",
+    [
+        (1, 8_388_608),
+        (10_000 * 8_388_608, 8_388_608),
+        (100e9, 16_777_216),
+        (200e9, 25_165_824),
+    ],
+)
+def test_accession_calculate_multipart_chunksize(
+    mock_accession, file_size_bytes, expected
+):
+    result = mock_accession._calculate_multipart_chunksize(file_size_bytes)
+    assert result == expected
+
+
 def mock_post_step_run(payload, *args, **kwargs):
     payload.update({"@id": "foo", "@type": ["AnalysisStepRun"]})
     return (payload, 200)
@@ -412,6 +445,46 @@ def test_accession_steps_dry_run(mocker: MockFixture, mock_accession: Accession)
     ]
 
 
+@pytest.mark.parametrize(
+    "kwargs", [{"dry_run": True}, {"dry_run": True, "force": True}]
+)
+def test_accession_steps_matches_dry_run(
+    caplog, mocker, mock_accession, matching_md5_record, kwargs
+):
+    """
+    Dry run shouldn't accession anything and has precendence over `force`
+    """
+    mocker.patch.object(mock_accession, "_get_dry_run_matches", return_value=[])
+    mocker.patch.object(mock_accession, "accession_step")
+    mock_accession.accession_steps(**kwargs)
+    assert "Dry run finished" in caplog.text
+    mock_accession.accession_step.assert_not_called()
+
+
+def test_accession_steps_matches_no_force(
+    caplog, mocker, mock_accession, matching_md5_record
+):
+    mocker.patch.object(
+        mock_accession, "_get_dry_run_matches", return_value=[matching_md5_record]
+    )
+    mocker.patch.object(mock_accession, "accession_step")
+    mock_accession.accession_steps(force=False)
+    assert "stopping accessioning" in caplog.text
+    mock_accession.accession_step.assert_not_called()
+
+
+def test_accession_steps_matches_with_force(
+    caplog, mocker, mock_accession, matching_md5_record
+):
+    mocker.patch.object(
+        mock_accession, "_get_dry_run_matches", return_value=[matching_md5_record]
+    )
+    mocker.patch.object(mock_accession, "accession_step")
+    mock_accession.accession_steps(force=True)
+    assert "continuing accessioning" in caplog.text
+    mock_accession.accession_step.assert_called()
+
+
 def test_accession_init(mock_accession: Accession, lab: str, award: str) -> None:
     assert mock_accession.common_metadata.lab == lab
     assert mock_accession.common_metadata.award == award
